@@ -3,7 +3,7 @@
 
 import re
 from time import time, mktime
-from datetime import datetime
+import datetime
 from dateutil.relativedelta import relativedelta
 
 search_re = re.compile(r'^([^-]+)-([^-/]+)(/(.*))?$')
@@ -51,7 +51,7 @@ class croniter(object):
                  'expression.'
     
     def __init__(self, expr_format, start_time=time()):
-        if isinstance(start_time, datetime):
+        if isinstance(start_time, datetime.datetime):
             start_time = mktime(start_time.timetuple())
 
         self.cur = start_time
@@ -120,7 +120,7 @@ class croniter(object):
     def _get_next(self, ret_type=float, is_prev=False):
         expanded = self.expanded[:]
 
-        if ret_type not in (float, datetime):
+        if ret_type not in (float, datetime.datetime):
             raise TypeError("Invalid ret_type, only 'float' or 'datetime' " \
                             "is acceptable.")
 
@@ -140,8 +140,8 @@ class croniter(object):
             result = self._calc(self.cur, expanded, is_prev)
         self.cur = result
 
-        if ret_type == datetime:
-            result = datetime.fromtimestamp(result)
+        if ret_type == datetime.datetime:
+            result = datetime.datetime.fromtimestamp(result)
         return result
     
     def _calc(self, now, expanded, is_prev):
@@ -153,7 +153,7 @@ class croniter(object):
             sign = 1
             
         offset = len(expanded) == 6 and 1 or 60
-        dst = now = datetime.fromtimestamp(now + sign * offset)
+        dst = now = datetime.datetime.fromtimestamp(now + sign * offset)
 
         day, month, year = dst.day, dst.month, dst.year
         current_year = now.year
@@ -166,11 +166,13 @@ class croniter(object):
                 if month == 2 and self.is_leap(year) == True:
                     days += 1
 
-                reset_day = days if is_prev else 1
+                reset_day = 1
 
                 if diff_month != None and diff_month != 0:
                     if is_prev:
                         d += relativedelta(months=diff_month)
+                        reset_day = DAYS[d.month - 1]
+                        d += relativedelta(day=reset_day, hour=23, minute=59, second=59)
                     else:
                         d += relativedelta(months=diff_month, day=reset_day,
                                            hour=0, minute=0, second=0)
@@ -191,7 +193,7 @@ class croniter(object):
 
                 if diff_day != None and diff_day != 0:
                     if is_prev:
-                        d += relativedelta(days=diff_day)
+                        d += relativedelta(days=diff_day, hour=23, minute=59, second=59)
                     else:
                         d += relativedelta(days=diff_day, hour=0, minute=0, second=0)
                     return True, d
@@ -202,7 +204,7 @@ class croniter(object):
                 diff_day_of_week = nearest_diff_method(d.isoweekday() % 7, expanded[4], 7)
                 if diff_day_of_week != None and diff_day_of_week != 0:
                     if is_prev:
-                        d += relativedelta(days=diff_day_of_week)
+                        d += relativedelta(days=diff_day_of_week, hour=23, minute=59, second=59)
                     else:
                         d += relativedelta(days=diff_day_of_week, hour=0, minute=0, second=0)
                     return True, d
@@ -213,7 +215,7 @@ class croniter(object):
                 diff_hour = nearest_diff_method(d.hour, expanded[1], 24)
                 if diff_hour != None and diff_hour != 0:
                     if is_prev:
-                        d += relativedelta(hours = diff_hour)
+                        d += relativedelta(hours = diff_hour, minute=59, second=59)
                     else:
                         d += relativedelta(hours = diff_hour, minute=0, second=0)
                     return True, d
@@ -224,7 +226,7 @@ class croniter(object):
                 diff_min = nearest_diff_method(d.minute, expanded[0], 60)
                 if diff_min != None and diff_min != 0:
                     if is_prev:
-                        d += relativedelta(minutes = diff_min)
+                        d += relativedelta(minutes = diff_min, second=59)
                     else:
                         d += relativedelta(minutes = diff_min, second=0)
                     return True, d
@@ -305,7 +307,7 @@ class croniter(object):
 
 if __name__ == '__main__':
 
-    base = datetime(2010, 1, 25)
+    base = datetime.datetime(2010, 1, 25)
     itr = croniter('0 0 1 * *', base)
-    n1 = itr.get_next(datetime)
+    n1 = itr.get_next(datetime.datetime)
     print n1
